def functionOfUserInput(parametricValue): #Input inside function allows for parametric study
    #-----------------------------------------------------------------
    #---------------------- 2D BEAM SCRIPT ---------------------------
    #--------- DIANA/Python framework for robust NLFEA of RC beams ---
    #-----------------------------------------------------------------
    #By Katja Hansen
    #If questions, please contact: katjahansen.mail@gmail.com 
    #This script is part of Katja Hansen's Master's Thesis, June 2022.  
    
    #-----------------------------------------------------------------------------------------
    #TABLE OF CONTENTS
    #1. INFO BEFORE CHANGING THE SCRIPT
        #1.1 FIRST TIME use of beam script
        #1.2 General project information
        #1.3 Units
        #1.4 Commenting and uncommenting
        #1.5 Empty templates
    #2. PARAMETRIC STUDY
    #3. EXTRA INFO
        #3.1 About coordinates
        #3.2 Creation of objects from a class
        #3.3 Explanation of lines
    #4. CREATING PROJECT
        #4.1 Modelling choices 
    #5. CREATING THE GEOMETRY
        #5.1 The beam
            #5.1.1 Geometry
        #5.2 Reinforcement
            #5.2.1 Cover
            #5.2.2 User defined variables
        #5.3 Longitudinal reinforcement
            #5.3.1 Creation of longitudinal reinforcement
        #5.4 Transverse reinforcement (shear)
            #5.4.1 Creation of transverse reinforcement
            #5.4.2 Spacing/positions of transverse reinforcement
        #5.5 Plates
            #5.5.1 Option 1: using template for 3-point bending
            #5.5.2 Option 2: using template for 4-point bending
            #5.5.3 Option 3: Creation of individual plates 		
    #6. LOADS
        #6.1 Option 1: using template for 3- or 4-point bending
        #6.2 Option 2: Creation of individual loads
    #7. MATERIAL MODELS
        #7.1 Concrete material model
            #7.1.1 Concrete properties
        #7.2 Steel plates material model
        #7.3 Reinforcement material model
    #8. STRUCTURAL INTERFACES
    #9. MESH	
    #10.ANALYSIS
        #10.1 Linear Analysis
            #10.1.1 RUN LINEAR ANALYSIS
        #10.2 Nonlinear Analysis
            #10.2.1 Arc length control
            #10.2.2 Load incrementation
            #10.2.3 Iteration method
            #10.2.4 Line search
            #10.2.5 Convergence criteria
            #10.2.6 Additional choices for analysis
            #10.2.7 RUN NONLINEAR ANALYSIS
    #11. OUTPUTS FROM NONLINEAR ANALYSIS
        #11.1 Analysis output
        #11.2 Load-displacement graph
        #11.3 Load-displacement CSV 
    #---------------------------------------------------------------------------------------
    
    ###1. INFO BEFORE CHANGING THE SCRIPT

    #-#1.1 FIRST TIME use of Beam Script: 
    ## You have to instal python modules to run the script in DIANA. 
    ## This is done in the following manner:  
    ## Open the DIANA Command Box (via the start menu on your computer)
    ## Choose "Run as administrator"
    ## Paste the following lines into the command box: 
    # %DIAPATH_W%\python\python -m pip install -t %DIAPATH_W%\modules numpy
    # %DIAPATH_W%\python\python -m pip install -t %DIAPATH_W%\modules matplotlib

    #-#1.2 General project information:
    ## Script A, B and C (A: UserInput, B: parametricStudy, C: classesAndFunctions, D: main), 
    ##should all be saved in the same working folder. 
    ## Script A: UserInput (and B: parametricStudy) can be changed by the user.
    ## A parametric study can be performed for one variable in the input script. See section 1.4. 
    ## To run a script in DIANA, choose File -> Run saved scripts
    ## Select and run either: 
    ## Script D: main #For creation of a beam
    ## Script B: parametricStrudy #For a parametric study
    ## Specified outputs, ex. csv-files, plots etc., will be created automatically and saved to a 
    ##user-specified directory path.

    #-#1.3 Units
    ##All input have to be in accordance with the chosen units for this script. 
    ##The following units are used for this script: 
    ## length = "MM"
    ## force = "N"
    ## mass = "T"
    ## temperature = "CELSIU"

    #-#1.4 Commenting and uncommenting: 
    ## Lines that can be commented/uncommented are marked with: **Optional**
    ## The default input will be used, unless an optional input is given.  
    ## Lines that are not relevant for your script should stay commented, using ctrl + k
    ## Relevant lines can be uncommented, using crtl + shift + k
    
    #-#1.5 Empty templates:
    ## Empty templates for creation of different objects are given as follows:
    ''' Empty template:
    Text that can be copied and filled with desired input 
    '''
    ## crtl + f can be used to replace template object name, with user defined name. 
    
    ###2. PARAMETRIC STUDY
    ## For a parametric studiy, multiple analyses will be performed. One parameter will be varied with
    ##different inputs, while the others stay the same. 
    ## A parametric study is performed by editing Script B: parametricStudy and Script A: UserInput. 
    ## In Script B, the input for the varying parameter is defined. 
    ## In Script A, the varying parameter has to be marked with the input parametricValue. See Example:
    '''Example
        beam.geometry.length = parametricValue
    '''

    #---------------------------------------------------------------------------------------------------
    ###3. EXTRA INFO (Do not have to read before using script)

    #-#3.1 About coordinates: 
    ## Beam has coordinates [x,y] = [0,0] in lower left corner. 
    ## Coordinate system starts in lower left corner of beam, with positive X to the right 
    ##and positive Y upwards. 
    ## Plates: x-coordinates refers to midpoint of plate. (= loadingpoint)
    ## Span: length between x-coordinate/midpoints of plates/loadingpoints. 
    ## All coordinates has 0 as its default value
    
    #-#3.2 Creation of objects from a class: 
    ## An object oriented structure is used for this script.
    ## All classes are defined in Script C: classesAndFunctions
    ## When an empty template is used to create objects of a class, the user is free to choose 
    ##the name of the object. 
    ## Unless otherwise specified, the user can create as many objects as desired. zero is also allowed. 
    ## The objectname of the object beam from the class Beam should not be changed. 

    #-#3.3 Explanation of lines: 
    ###  NEW SECTION
    #-# Subsection
    #'# Subsubsection
    ## Text
    #remark/explanation
    #** optional **
    ##Option i: choose one of the available options if required
    ''' Empty template
    Text that can be copied and filled with desired input 
    crtl + f can be used to replace template object name, with user defined name.  
    ''' 
    #\\ Add your own comments as a user 

    #-----------------------------------------------------------------------------------------------
    ###4. CREATING PROJECT
    ##dirPath is the directory path of the project (= Where your files should be saved)
    ##path=r.....don't forget r before the working path. For example:
    ##Project.dirPath = r"C:\Users\katja\OneDrive - NTNU\Documents\master"
    ##By default, the project is saved in the same folder as the where the Python scripts are saved. 
    ##By default the project name is generated as follows: 
    ##Project.name = Project.modelName + "_" + TodaysDate + "_" + Project.modelExtraInfo 
    
    Project.modelName = "TestBeam"
    Project.modelExtraInfo = "default"
    
    ##The following can be changed: 
    # Project.dirPath = #**Optional**
    # Project.name = #**Optional**

    Project.size_in_m = 1000 

    #-#4.1 Modelling choices 
    ## The beam will be modelled in 2D
    ## The whole beam is modelled by default. 
    
    ## If the following option is chosen, only half the beam will be modelled: 
    # Options.symmetric_Beam =  True #**Optional**, default is False

    ###5. CREATING THE GEOMETRY 
    #-#5.1 The beam 
    #'#5.1.1 Geometry: 
    beam = Beam() #creating beam object
    beamGeometry = Geometry() #creating geometry object 
    beam.add_geometry(beamGeometry) #adding the geometry to the beam

    beam.geometry.length = 6000 #[mm] 
    beam.geometry.height = 600 #[mm]
    beam.geometry.width = 400 #[mm] #thickness

    #-#5.2 Reinforcement
    ##Embedded reinforcement bars is the only implemented type of reinforcement. 

    #'#5.2.1 Cover: #**Optional input**
    ##Cover is an optional object, which can be used for your convinience: 
    cover = Cover() #creating cover object
    ##Choose one of the options. 
    ##The section with the chosen option should be uncommented, 
    ##while the other options should be commented.  

    # ##**Option 1**: definition of each cover
    cover.side = 48 #[mm] 
    cover.top = 50 #[mm]	
    cover.bot = 64 #[mm]	

    ##**Option 2**: all sides have same cover: 
    # cover.length = 100 #[mm]	
    # cover.side = cover.top = cover.bot = cover.length 
    
    #'#5.2.2 User defined variables
    ##Here new parameters can be defined by the user to easier create the reinforcement.
    ##The following parameter is suggested:  
    # diameterOfBars =  #**Optional**

    #-#5.3 Longitudinal reinforcement 
    ##Define as many longitudinal reinfocement bars as desired. (To create 0 is also allowed))
    ##The user is free to choose the name of each object. 
    ##Longitudinal reinforcement is created as follows: 
    ##nameOfBar = Longitudinal_Reinfo(Name, As, F_y, F_u, Epsilon_u, (E_mod))
    ##As = cross section area[mm^2], F_y = yield strength [N/mm^2], F_u = ultimate strength [N/mm^2],
    ##Epsilon_u = ultimate strain []
    ##Default value of 200000 for Youngs modulus (E_mod) if no value is given. [N/mm^2]
    ##x- and y- coordinates does also have to be defined, for each reinfo bar. 

    ## About coordinates: 
    ##Beam has coordinates [x,y] = [0,0] in lower left corner. 
    ##Coordinate system starts in lower left corner of beam, 
    ##with positive X to the right and positive Y upwards. 

    ##Examples of the creation of longitudinal reinforcement bars: 
    '''Example block (can be copied and changed to create your own objects)
    #
    upper_reinfo = Longitudinal_Reinfo("upper", 300, 315, 460, 2.3425E-2)
    upper_reinfo.y_coord = beam.geometry.height - cover.top
    upper_reinfo.x_coord_start = cover.side 
    # upper_reinfo.x_coord_end = beam.geometry.length - cover.side #**Input if beam is not symmetric**

    #   
    ReinfoLow = Longitudinal_Reinfo("lower", 1400, 436, 700, 4.78E-2, 220000)
    ReinfoLow.y_coord = 20
    ReinfoLow.x_coord_start = 0 
    # ReinfoLow.x_coord_end = beam.geometry.length #**Input needed if beam is not symmetric**
    '''

    ##Copy this block to create long.reinfo objects: 
    ''' Empty template
    templateName = Longitudinal_Reinfo( )
    templateName.y_coord = 
    templateName.x_coord_start = 
    # templateName.x_coord_end = #**Input needed if beam is not symmetric**
    '''  

    #'#5.3.1 Creation of longitudinal reinforcement
    ##CREATE YOUR LONG.REINFO OBJECTS HERE

    #-#5.4 Transverse reinforcement (shear)
    ##All shear bars will have the same material properties. 
    ##, which means only one object should be created for shear reinforcement. 
    ##nameOfBar = Transverse_Reinfo(Name, As, F_ym, F_um, Epsilon_u, (E_mod)). 
    ##As = cross section area[mm^2], F_y = yield strength [N/mm^2], F_u = ultimate strength [N/mm^2],
    ##Epsilon_u = ultimate strain []
    ##Default value of 200000 for Youngs modulus (E_mod) if no value is given. [N/mm^2]
    ##y-coordinates does also have to be defined. 
    
    ##Examples of the creation of transverse reinfo:
    '''Example block (can be copied and changed to create your own objects)
    shear_reinfo = Transverse_Reinfo("Shear_reinfo", 25.7, 600, 651, 4.70E-2,220000)
    shear_reinfo.y_coord_bot = cover.bot
    shear_reinfo.y_coord_top = beam.geometry.height - cover.top
    '''
    
    ##Copy this block to create trans.reinfo objects:
    ''' Empty template
    ##You should maximum create one object!
    templateName = Transverse_Reinfo( )
    templateName.y_coord_bot = 
    templateName.y_coord_top = 
    '''  
    
    #'#5.4.1 Creation of transverse reinforcement
    ##CREATE YOUR TRANS. REINFO OBJECT HERE

    #'#5.4.2 Spacing/positions of transverse reinforcement: 
    ##The transverse reinforcement is divided into sections with the same spacing. 
    ##You can create one or multiple sections.
    ##If the transverse reinforcement object is created, at least one section have to be defined.
    ##If the beam is symmetric, you only have to create sections for half the beam.
    ##A section is created as follows: 
    ## section_i = Section(spacing, x_coord_start, x_coord_end) #All three inputs are int

    ## About coordinates: 
    ##Beam has coordinates [x,y] = [0,0] in lower left corner. 
    ##Coordinate system starts in lower left corner of beam, 
    ##with positive X to the right and positive Y upwards. 

    ##Examples of the creation of sections: 
    '''Example block (can be copied and changed to create your own objects)
    #Ex. 1: 
    section = Section(10, cover.side, beam.geometry.length - cover.side)

    #Ex. 2: 
    spacing_large = 168
    spacing_small = 86
    section_1 = Section(spacing_small, cover.side, cover.side + 4*spacing_small)
    
    section_2 = Section(spacing_large, cover.side + 4*spacing_small, 
    (beam.geometry.length/2) - 2*spacing_small)
    
    section_3 = Section(spacing_small, (beam.geometry.length/2) - 2*spacing_small, beam.geometry.length)
    '''
    
    ##Copy this block to create section objects: 
    ''' Empty template
    templateName = Section( )
    ''' 
    
    ##CREATE YOUR SECTION OBJECTS HERE
    
    #-#5.5 Plates
    ##Available plates are loading plates (L) and support plates (S)
    ##All plates will have the same geometry. 
    ##The width/thickness of the plates will be equal to the beam thickness
    plateGeometry = Geometry() #creating geometry object for plates

    plateGeometry.length = 150  #[mm]
    plateGeometry.height = 35 #[mm]

    ##Choose one of the following options to create the plates.
    ##The section with the chosen option should be uncommented, 
    ##while the other options should be commented.  
    ##Option 1 and 2 are templates for bending tests. Setup is shown in master thesis. 
    
    #'#5.5.1 Option 1: using template for 3-point bending
    Options.template_3PointBending = True
    beam.geometry.lengthOfSpan = beam.geometry.length - 400 #[mm]

    #'#5.5.2 Option 2: using template for 4-point bending
    # Options.template_4PointBending = True
    # beam.geometry.lengthOfSpan = 5000 #[mm]
    # beam.geometry.lengthOfInnerSpan = 3000 #[mm]

    #'#5.5.3 Option 3: Creation of individual plates 
    ##Plates are creating by specifying the x-coordinate of the midpoint (loading point)
    ##The user is free to choose the name of each object. 
    ##Each plate is created as follows: 
    ##nameOfPlate = Plates(typeOfPlate, name, x_coord)
    ##typeOfPlate = "S" (supportplate)  or "L" (loadingplate)
    ##name = string, x_coord = int
    ##By default translations are fixed in both x- and y-direction for support plates. Can be changed: 
    ##To change BC's for support plates, use: 
    ##plateObject.fixedTranslation_y = False or plateObject.fixedTranslation_x = False 

    ## About coordinates: 
    ##Beam has coordinates [x,y] = [0,0] in lower left corner. 
    ##Coordinate system starts in lower left corner of beam, 
    ##with positive X to the right and positive Y upwards. 

    ##Examples of the creation of plates: 
    '''Example block (can be copied and changed to create your own objects)
    sup_plate1 = Plates("S", "Support plate 1", 50) 
    sup_plate1.fixedTranslation_y = False #**Optional**
    # sup_plate1.fixedTranslation_x = False #**Optional**
    load_plate1 = Plates("L", "Loading plate 1", 70) 
    load_plate2 = Plates("L", "Loading plate 2", 100)
    '''
    
    ##Copy this block to create plate objects: 
    '''Empty template
    templateName = Plates(  ) 
    # nameOfPlate.fixedTranslation_y = False #**Optional**
    # nameOfPlate.fixedTranslation_x = False #**Optional**
    '''
    
    ##CREATE YOUR PLATE OBJECTS HERE (option 3)

    ###6. LOADS
    ##The dead weight is applied in the first load step.
    ##Then point loads can be applied. (Only point loads are implemented)
    ##Loads are defined as follows: 
    ##load = Loads(typeOfLoad, name, value, direction)
    ##typeOfLoad = "Point" (Only point loads are implemented)
    ##name = str
    ##value: int or double. OBS! positive y-axis is upwards, NEGATIVE LOADS ACTS DOWNWARDS
    ##direction = "X", "Y". 

    #-#6.1 Option 1: using template for 3- or 4-point bending
    ##Both loads are assumed to have same value for 4-point bending. Only one has to be defined. 
    load = Loads("Point", "Load", -1000, "Y") 

    #-#6.2 Option 2: Creation of individual loads
    ##Each load should have a plate object as its target. 
    ##A target is defined as follows:
    #load.target = plateobject
    
    ##Examples of the creation of point loads: 
    '''Example block (can be copied and changed to create your own objects)
    load1 = Loads("Point", "Load 1", -1000, "Y")
    load1.target = plate1 
    load2 = Loads("Point", "Load 2", -200, "Y") 
    load2.target = plate2 
    '''
    
    ##Copy this block to create point load objects: 
    '''Empty template
    templateName_Load = Loads()
    templateName_Load.target = templateName_Plate
    '''
    
    ##CREATE YOUR LOAD OBJECTS HERE (option 2)
        
    ###7. MATERIAL MODELS
    #-#7.1 Concrete material model
    #The concrete material is defined as follows: concrete = Concrete(f_ck)
    concrete = Concrete(30)

    #'#7.1.1 Concrete properties:
    ##The recommended material model used recommended material properties by default. 
    ##These are based on EC2, fib2010 and RTD*.
    ##See Script C, Concrete class for default parameters
    ##The properties can be changed by uncommenting the desired lines. 
    ##The properties that remains commented, will use recommended values. 
    ##If recommended curves are changed, the script is not guaranteed to run
    ##since additional parameters might be needed.

    ## The following properties can be changed:
    # concrete.Youngs_modulus = #**Optional**
    # concrete.poissons_ratio = #**Optional**
    # concrete.mass_density = #**Optional**
    # concrete.tensile_strength = #**Optional**
    # concrete.compressive_strength =  #**Optional**
    # concrete.tensile_FractureEnergy = #**Optional**
    # concrete.compressive_FractureEnergy = #**Optional**
    # concrete.aggregate_type = #**Optional**
    # concrete.tensile_curve = "HORDYK" #**Optional**
    # concrete.crackBandwidt_specification = #**Optional**
    # concrete.poissonsRatio_reductionModel = #**Optional**
    # concrete.compression_curve = #**Optional**
    # concret.lateralCracking_reductionModel = #**Optional**
    # concrete.lateralCracking_reductionCurve_lowerBound =  #**Optional**
    # concrete.confinementModel = "NONE" #**Optional**

    #-#7.2 Steel plates material model
    #A linear-elastic behaviour is assumed for the plates

    Steel_Plates.e_mod = 2000000
    Steel_Plates.poissons_ratio = 0.3

    #-#7.3 Reinforcement material model
    ##Only default material for reinforcement has been implemented.
    ##The chosen material model is Von Mises Plasticity, with a bilinear strain-stress diagram. 
    ##DIANA default settings for hardening behaviour are used.

    ###8. STRUCTURAL INTERFACES 
    ##A no-tension/no-friction 2D line interface is defined between 
    ##the steel plates and the concrete beam.
    ##A high value for the normal compressive stiffness and a low value for the shear stiffness 
    ##and normal tensile stiffness will be used as befault. 
    ##A diagram based on the normal compressive and tensile stiffness is used 
    ##to define the nonlinear relation. 

    ## The following properties can be changed:
    # Interface.Knn_tension     =   # [N/mm3] **Optional**
    # Interface.Knn_compression =   # [N/mm3] **Optional**
    # Interface.Kt              =   # [N/mm3] **Optional**
    
    ###9. MESH
    ##Recommended mesh is used as default. 
    ##Maximum elementsize = min(beam.Length/50, beam.Height/6)
    Mesh.elementsize = 25 #[mm]

    ## The following properties can be changed:
    # Mesh.meshorder =  #**Optional**
    # Mesh.meshertype =  #**Optional**

    ###10. ANALYSIS
    ##It is recommended to run a linear analysis before running the nonlinear analysis. 
    ##runsolver = True runs the analysis. Default value is false. 
    ##Linear and nonlinear analysis have been implemented. 
    ##An analysis is defined as follows: 
    ##Analysis(_name, _typeOfAnalysis) 
    ##_name = str, _typeOfAnalysis = "Linear" or "Nonlinear"

    #-#10.1 Linear Analysis
    ##DIANA Primary output is chosen for the linear analysis.
    LFEA = Analysis("Linear analysis", "Linear") #creating linear static analysis
    
    ## The following properties can be changed:
    # LFEA.method = **Optional input**
    # LFEA.output = **Optional input**
    
    #'#10.1.1 RUN LINEAR ANALYSIS
    ##To run the linear analysis, uncomment the following line:  
    # LFEA.runSolver = True #**Optional**

    #-#10.2 Nonlinear Analysis
    NLFEA = Analysis("Nonlinear analysis", "Nonlinear") #creating nonlinear analysis

    #'#10.2.1 Arc length control: 
    ##Arc length control is strongly recommended. 
    ##The arc length control will be applied over the whole beam. 
    NLFEA.arcLengthControl = True #**Default and strongly recommended as true**

    #'#10.2.2 Load incrementation:
    ##Load control is applied (in combination with arc length control). 
    ##As recommended, the load incrementation uses an automatic procedure. 
    ##Energy based adaptive loading is the only implemented method. This method must
    ##be combined with arc length control. 
    incrementation = Incrementation() #Creating an incrementation object
    NLFEA.setIncrementalMethod(incrementation) #adding incremental method to the analysis

    ##Option 1: Energy based adaptive loading
    ##The energy based method MUST be combined with arc length control. 
    incrementation.method = "ENERGY"
    incrementation.initial_step_size = 5    #initial size for the first step
    incrementation.max_step_size = 10       #upper limit of the step size
    incrementation.min_step_size = 3        #lower limit of the step size
    incrementation.nrOfSteps = 150          #maximum number of steps

    #'#10.2.3 Iteration method:
    ##Only Newton-Raphson methods have been implemented. 
    ##Choose one of the options. The section with the chosen option should be uncommented,
    ##while the other options should be commented.  
    iteration = Iteration() #creating iteration object
    NLFEA.setIterationMethod(iteration) #adding iterative procedure to the analysis

    ## Option 1: Regular Newton-Raphson
    iteration.method = "NEWTON-RAPHSON"
    iteration.typeOfMethod = "REGULA"
    iteration.nrOfIterations = 100 

    ## Option 2: Modified Newton-Raphson
    # iteration.method = "NEWTON-RAPHSON"
    # iteration.typeOfMethod = "MODIFI"
    # iteration.nrOfIterations = 100
    
    ## The following properties can be changed:
    # iteration.firstStiffnessMatrix = **Optional input**
    
    #'#10.2.4 Line search: 
    ##Using a line search algorithm is recommended. 
    NLFEA.lineSearch = True #**Default and recommended as true**
   
    #'#10.2.5 Convergence criteria: 
    ##One or multiple convergence criteria MUST be chosen. 
    ##Recommended to use a force norm and an energy norm. 
    ##Choose one of the options. Optional to choose one or more convergence criteria.  
    convergence = Convergence()         #creating convergence object
    NLFEA.setConvergence(convergence)   #adding convergence criteria to the analysis

    convergence.useForceNorm = True     #**Default and recommended as true**
    convergence.useEnergyNorm = True    #**Default and recommended as true**
    convergence.useDispNorm = False     #**Default and recommended as false**

    ## Option 1: Suggested tolerances
    ##Force norm: 
    convergence.forceNorm = 0.01 
    convergence.forceNorm_deadLoad = 0.05         
    ##Energy norm: 
    convergence.energyNorm = 0.001
    convergence.energyNorm_deadLoad = 0.01        
        
    ## Option 2: Choose your own tolerances:
    ##For this option, one or multiple convergence criteria MUST be chosen. 
    
    ##Force norm: 
    # convergence.forceNorm = 
    # convergence.forceNorm_deadLoad =      
    
    ##Energy norm:
    # convergence.energyNorm = 
    # convergence.energyNorm_deadLoad  =   
    
    ##Displacement norm: 
    # convergence.dispNorm =              
    # convergence.energyNorm_deadLoad  =               
    
    #'#10.2.6 Additional choices for analysis
    NLFEA.allConvergenceNormsHaveToBeSatisfied = False  #**Default and recommended as false**
    NLFEA.continueIfNoConvergence = True                #**Default and recommended as true**
    
    #'#10.2.7 RUN NONLINEAR ANALYSIS
    ##To run the analysis, uncomment the following line:  
    # NLFEA.runSolver = True #**optional**

    ###11. OUTPUTS FROM NONLINEAR ANALYSIS
    ##Outputs will be saved to the specified directory at beginning.  
    ## All outputs are optional. Comment or write False to not include output.
    
    #-#11.1 Analysis output: 
    NLFEA.output = {
        "DISPLA TOTAL TRANSL GLOBAL" : True,    #**Optional**
        "FORCE REACTI TRANSL GLOBAL" : True,    #**Optional**
        "STRAIN TOTAL GREEN GLOBAL" : True,     #**Optional**
        "STRAIN TOTAL GREEN PRINCI" : True,     #**Optional**
        "STRAIN CRKWDT GREEN GLOBAL" : True,    #**Optional**
        "STRAIN CRACK GREEN" : True,            #**Optional**
        "STRAIN CRKWDT GREEN PRINCI" : True,    #**Optional**
        "STRESS TOTAL CAUCHY GLOBAL" : True,    #**Optional**
        "STRESS TOTAL CAUCHY PRINCI" : True     #**Optional**
    }
    
    #-#11.2 Load-displacement graph (displacement in y-dir) **Optional**
    #Edit and uncomment this section to generate a load-displacement graph.
    ##Downward displacement is defined as positive by default. 
    
    # #Specify the coordinates of the point where the displacement will be retrived. 
    # LoadDispY_Graph.x_coord = beam.geometry.length/2 #[mm]
    # LoadDispY_Graph.y_coord = 0 #[mm]
    
    # ##The following options can be changed: 
    # ##x_label, y_label = str
    # ##xLim, y_Lim = [lowerBound, upperBound]; lowerBound, upperBound = int
    # # Scalefactor.loadFactor_plot = #**optional**
    # # Scalefactor.displacement_plot = #**optional**
    # # LoadDispY_Graph.xlabel = #**optional**
    # # LoadDispY_Graph.ylabel = #**optional**
    # # LoadDispY_Graph.xLim = #**optional**
    # # LoadDispY_Graph.yLim =  #**optional**
    
    #-#11.3 Load-displacement CSV (displacement in y-dir)**Optional**
    ##Edit and uncomment this section to generate a 
    ##CSV-file for load-displacement at specified coordinate.
    ##Downward displacement is defined as positive by default. 
    ##The CSV-file will have the following format: 
    ##  (Scaled) Loadfactor;(Scaled) Displacement
    ##  1.00;0.50
    ##  2.30;0.65
        
    # ##Specify the coordinates of the point for which the CSV-file will be generated:
    # LoadDispY_CSV.x_coord = beam.geometry.length/2 #[mm]
    # LoadDispY_CSV.y_coord = 0 #[mm]
    
    # #The following options can be changed: 
    # # Scalefactor.loadFactor_CSV =  #**optional**
    # # Scalefactor.displacement_CSV = #**optional**
    # # LoadDispY_CSV.decimalPlaces = #**optional**

    
    #-------------------------------------------------------------------------------------   
    ## Additional info: 
    #*RTD = Rijkwaterstaat Technincal Document: Guidelines for NLFEA of Concrete Structures
    globals().update(locals()) #Allows main script to access all variables in function as globals
    return 

